@@ -1,6 +1,6 @@
 
-#ifndef __ARCTAN_H
-#define __ARCTAN_H
+#ifndef xxARCTAN_H
+#define xxARCTAN_H
 
 
 class ArcTan{
@@ -20,19 +20,19 @@ public:
     p=0;
   }
   
-  ArcTan(int _p, int _n) // Constructor
-    : Out(_p, _n), dOut(_p, _n) { // Default matrix member variable initialization
+  ArcTan(int xp, int xn) // Constructor
+    : Out(xp, xn), dOut(xp, xn) { // Default matrix member variable initialization
     
-    n = _n;
-    p = _p;
+    n = xn;
+    p = xp;
     
   }
   
   arma::mat Get_Out();
   arma::mat Get_dOut();
   
-  void forward(arma::mat _X);
-  void backward(arma::mat _X, arma::mat _dOut);
+  void forward(arma::mat xX);
+  void backward(arma::mat xX, arma::mat xdOut);
   
   
 };
@@ -53,8 +53,8 @@ void ArcTan::forward(arma::mat X){
 }
 
 
-void ArcTan::backward(arma::mat _X, arma::mat _dOut){
-  dOut = _dOut/(1+_X%_X) ;
+void ArcTan::backward(arma::mat xX, arma::mat xdOut){
+  dOut = xdOut/(1+xX%xX) ;
 
 }
 
